/**
        \file error.h
        \author Sachith Dunatunga
        \date 21.04.09
        \brief The header/interface for libparagon errors.
*/
#ifndef __PARAGON_ERROR_H__
#define __PARAGON_ERROR_H__

/* ---libparagon----------------------------------------------------------- */
/**
        \defgroup errors Error Codes
                The list of possible errorcodes libparagon functions can
        return.
        @{
*/
/**
        \brief Returned on success.
*/
#define PARAGON_SUCCESS (0)
/**
        \brief Returned when the passed arguments have an unexpected format.
*/
#define PARAGON_BADARG (-1)
/**
        \brief Returned when openusb has an error.
*/
#define PARAGON_OPENUSB_ERROR (-2)
/**
        \brief Returned when no phone was found.
*/
#define PARAGON_NO_PHONE (-3)
/**
        \brief Returned when a mode switch was unsuccessful.
*/
#define PARAGON_MODE_ERROR (-4)
/**
        \brief Returned when we run out of memory.
*/
#define PARAGON_NO_MEMORY (-5)
/**
        \brief Returned when the timer is interrupted.
*/
#define PARAGON_TIMING_ERROR (-6)
/**
        \brief Returned when there is an unspecified FSAC error.
*/
#define PARAGON_FSAC_ERROR (-7)
/**
        \brief Returned where there is an error when sending a command.
*/
#define PARAGON_COMMAND_ERROR (-8)
/**
        @}
*/

/**
        \brief Returns a human-readable string detailing the error.
        \param err The error to check (usually a return value).

        This function just looks up the error in the error table.
*/
char *paragon_strerror(int err);
/* ------------------------------------------------------------------------ */
#endif
