/**
        \file seem.h
        \author Sachith Dunatunga
        \date 21.04.09
        \brief The header/interface for paragon commands to manipulate
        seems (Binary motorola phone settings).
*/
#ifndef __PARAGON_SEEM_H__
#define __PARAGON_SEEM_H__
#include "handle.h"

/* ---libparagon----------------------------------------------------------- */
/**
        \brief This structure is used to store seems (binary motorola phone
        settings).

        We use this structure for sending and receiving seems.
*/
struct paragon_seem_s {
        /**
                \brief The seem number.
        */
        int number;
        /**
                \brief The seem record.
        */
        int record;
        /**
                \brief The seem offset.
        */
        int offset;
        /**
                \brief The seem data.
        */
        unsigned char *data;
        /**
                \brief The length (in bytes) of the data.
        */
        int data_len;
};

/**
        \brief A typedef to improve readability.
*/
typedef struct paragon_seem_s paragon_seem_t;

/**
        \brief This function reads a seem from the phone.
        \param handle The libparagon handle to use.
        \param number The seem number to download.
        \param record The seem record to download.
        \param recv A pointer to the seem structure to hold the result.
        \return PARAGON_SUCCESS on success, an integer less than 0 on failure.
        \warning Be sure to free the 'seem->data' pointer when you are done.

        This command will save the specified record to the seem pointed to
        by 'recv'. 'recv->data' should be NULL; otherwise, you will lose your
        pointer to the original recv->data. It expects the phone to be in
        P2K mode; if it is not, this command will fail with
        PARAGON_MODE_ERROR. The size of the data stored is saved under
        'seem->data_len'.
*/
int paragon_read_seem(paragon_handle_t *handle, int number, int record,
        paragon_seem_t *recv);

/**
        \brief This function writes a seem to the phone.
        \param handle The libparagon handle to use.
        \param trans A pointer to the seem structure to send.
        \return PARAGON_SUCCESS on success, an integer less than 0 on failure.

        This command will send the seem specified by 'trans' to the phone. It
        will not touch the actual data except to copy it into an internal
        buffer. It expects the phone to be in P2K mode; if it is not, this
        command will fail with PARAGON_MODE_ERROR.
*/
int paragon_write_seem(paragon_handle_t *handle, paragon_seem_t *trans);
/* ------------------------------------------------------------------------ */
#endif
