/**
        \file timings.h
        \author Sachith Dunatunga
        \date 21.04.09
        \brief The header for various empirically based timing information.
*/
#ifndef __PARAGON_TIMINGS_H__
#define __PARAGON_TIMINGS_H__

/* ---libparagon----------------------------------------------------------- */
/**
        \defgroup timings Transfer Timings
                The different timings libparagon uses for modeswitches,
                transfers, etc.
        @{
*/
/**
        \brief The default bulk transfer timeout (in milliseconds).
*/
#define PARAGON_BULK_DEFAULT_TIMEOUT (5000)
/**
        \brief The default control transfer timeout (in milliseconds).
*/
#define PARAGON_CTRL_DEFAULT_TIMEOUT (1000)
/**
        \brief How long to wait for ACM device initialization
        (in microseconds).

        Since we go through the kernel driver for this one, we don't have to
        worry so much (it buffers output until the device is ready), but we
        probably should wait a bit before sending the next command.
*/
#define PARAGON_ACM_INIT_WAIT (10 * 1000)
/**
        \brief How long to wait for AT device initialization
        (in microseconds).

        We have to do this because the phone (at least mine) is somewhat slow
        about accepting commands after the initialization string.
*/
#define PARAGON_AT_INIT_WAIT (50 * 1000)
/**
        \brief How long to wait after a modeswitch before rescanning the bus
        (in microseconds).

        This usually takes a while, and it'll fail if we don't wait enough.
        Experimentally, I find that a value of 5 - 7 seconds works well for
        my phone.
*/
#define PARAGON_MODESWITCH_WAIT (5000 * 1000)
/**
        @}
*/

/**
        \brief Sleeps for at least 'usec' microseconds.
        \param usec The number of microseconds to sleep for.
        \return PARAGON_SUCCESS on success, an integer less than 0 on error.
        \warning The granularity of the timer may be larger than 1
        millisecond; in this case we sleep for at least 'usec' microseconds.
        The actual amount of sleep time may be much larger.

        This function is just a wrapper to an actual sleep function.
*/
int paragon_usleep(int usec);
/* ------------------------------------------------------------------------ */
#endif
